==> trend_etl-1.0.1.tar.gz: trend_etl-1.0.1/trend_etl/tasks/load_submissions.py <==
import argparse
from typing import cast

from delta.tables import DeltaTable
from pyspark.sql import SparkSession

from trend_etl.functions.index import (
    full_table_name,
    submissions_upsert_to_delta,
    get_silver_table,
)
from trend_etl.transform.submissions import from_bronze_get_submissions_df
import trend_etl.schema.args as arguments
from trend_etl.schema.types import Merge_Strategy

program = "load_submissions"


def main() -> None:
    parser = argparse.ArgumentParser(description=f"Arguments for Trend ETL/{program}.")

    parser.add_argument(
        "--bronze-catalog",
        dest="bronze_catalog",
        required=True,
        choices=arguments.catalogs,
        help="The unit catalog to use",
    )

    parser.add_argument(
        "--target-catalog",
        dest="target_catalog",
        required=True,
        choices=arguments.catalogs,
        help="The unit catalog to use",
    )

    parser.add_argument(
        "--checkpoints-path-prefix",
        dest="checkpoints_path_prefix",
        required=True,
        help="The path to the folder (in S3) to store the checkpoints for this table",
    )

    parser.add_argument(
        "--keep-oldest",
        dest="keep_oldest",
        required=True,
        choices=arguments.yesno,
        help="Keep newest or oldest when using the merge to drop duplicates",
    )

    args = parser.parse_args()

    spark = cast(SparkSession, SparkSession.builder.appName(program).getOrCreate())

    kafka_submissions_table = full_table_name(
        args.bronze_catalog,
        arguments.schemas[arguments.schemas_bronze],
        arguments.tables[arguments.tables_submissions],
    )
    streaming_kafka_submissions = spark.readStream.format("delta").table(
        kafka_submissions_table
    )

    subreddit_idents_table = full_table_name(
        args.target_catalog,
        arguments.schemas[arguments.schemas_silver],
        arguments.tables[arguments.tables_subreddit_idents],
    )
    subreddit_idents = spark.read.format("delta").table(subreddit_idents_table)

    submission_idents_table = full_table_name(
        args.target_catalog,
        arguments.schemas[arguments.schemas_silver],
        arguments.tables[arguments.tables_submission_idents],
    )
    submission_idents = spark.read.format("delta").table(submission_idents_table)

    bots_table = full_table_name(
        args.target_catalog,
        arguments.schemas[arguments.schemas_silver],
        arguments.tables[arguments.tables_reddit_bot_users],
    )
    bots = spark.read.format("delta").table(bots_table)

    reddit_submissions_table = full_table_name(
        args.target_catalog,
        arguments.schemas[arguments.schemas_silver],
        get_silver_table(args.target_catalog, arguments.tables_reddit_submissions),
    )
    checkpoint_loc = f"{args.checkpoints_path_prefix}/{arguments.tables[arguments.tables_reddit_submissions]}"
    delta_table = DeltaTable.forName(spark, reddit_submissions_table)
    strategy: Merge_Strategy = (
        "keep-oldest" if args.keep_oldest == "yes" else "keep-newest"
    )

    (
        from_bronze_get_submissions_df(
            streaming_kafka_submissions, subreddit_idents, submission_idents, bots
        )
        .writeStream.format("delta")
        .foreachBatch(
            lambda batch_df, batch_id: submissions_upsert_to_delta(
                delta_table, strategy, batch_df
            )
        )
        .option("checkpointLocation", checkpoint_loc)
        .outputMode("append")
        .trigger(availableNow=True)
        .start()
    )


if __name__ == "__main__":
    main()

==> trend_etl-1.4.7.tar.gz: trend_etl-1.4.7/trend_etl/tasks/load_submissions.py <==
import argparse
from typing import cast

from delta.tables import DeltaTable
from pyspark.sql import SparkSession

from trend_etl.functions.index import (
    full_table_name,
    submissions_upsert_to_delta,
    get_silver_table,
)
from trend_etl.transform.submissions import from_bronze_get_submissions_df
import trend_etl.schema.args as arguments
from trend_etl.schema.types import Merge_Strategy

program = "load_submissions"


def main() -> None:
    parser = argparse.ArgumentParser(description=f"Arguments for Trend ETL/{program}.")

    parser.add_argument(
        "--bronze-catalog",
        dest="bronze_catalog",
        required=True,
        choices=arguments.catalogs,
        help="The unit catalog to use",
    )

    parser.add_argument(
        "--target-catalog",
        dest="target_catalog",
        required=True,
        choices=arguments.catalogs,
        help="The unit catalog to use",
    )

    parser.add_argument(
        "--checkpoints-path-prefix",
        dest="checkpoints_path_prefix",
        required=True,
        help="The path to the folder (in S3) to store the checkpoints for this table",
    )

    parser.add_argument(
        "--keep-oldest",
        dest="keep_oldest",
        required=True,
        choices=arguments.yesno,
        help="Keep newest or oldest when using the merge to drop duplicates",
    )

    args = parser.parse_args()

    spark = cast(SparkSession, SparkSession.builder.appName(program).getOrCreate())

    kafka_submissions_table = full_table_name(
        args.bronze_catalog,
        arguments.schemas[arguments.schemas_bronze],
        arguments.tables[arguments.tables_submissions],
    )
    streaming_kafka_submissions = spark.readStream.format("delta").table(
        kafka_submissions_table
    )

    subreddit_idents_table = full_table_name(
        args.target_catalog,
        arguments.schemas[arguments.schemas_silver],
        arguments.tables[arguments.tables_subreddit_idents],
    )
    subreddit_idents = spark.read.format("delta").table(subreddit_idents_table)

    submission_idents_table = full_table_name(
        args.target_catalog,
        arguments.schemas[arguments.schemas_silver],
        arguments.tables[arguments.tables_submission_idents],
    )
    submission_idents = spark.read.format("delta").table(submission_idents_table)

    bots_table = full_table_name(
        args.target_catalog,
        arguments.schemas[arguments.schemas_silver],
        arguments.tables[arguments.tables_reddit_bot_users],
    )
    bots = spark.read.format("delta").table(bots_table)

    reddit_submissions_table = full_table_name(
        args.target_catalog,
        arguments.schemas[arguments.schemas_silver],
        get_silver_table(args.target_catalog, arguments.tables_reddit_submissions),
    )
    checkpoint_loc = f"{args.checkpoints_path_prefix}/reddit_submissions_noparts"
    delta_table = DeltaTable.forName(spark, reddit_submissions_table)
    strategy: Merge_Strategy = (
        "keep-oldest" if args.keep_oldest == "yes" else "keep-newest"
    )

    (
        from_bronze_get_submissions_df(
            streaming_kafka_submissions, subreddit_idents, submission_idents, bots
        )
        .writeStream.format("delta")
        .foreachBatch(
            lambda batch_df, batch_id: submissions_upsert_to_delta(
                delta_table, strategy, batch_df
            )
        )
        .option("checkpointLocation", checkpoint_loc)
        .outputMode("append")
        .trigger(availableNow=True)
        .start()
    )


if __name__ == "__main__":
    main()
